@@ -15,10 +15,12 @@ from sktime.datatypes._examples import get_examples
 from sktime.datatypes._registry import (
     MTYPE_LIST_PANEL,
     MTYPE_LIST_SERIES,
+    MTYPE_LIST_TABLE,
     MTYPE_REGISTER,
     SCITYPE_REGISTER,
     mtype_to_scitype,
 )
+from sktime.datatypes._vectorize import VectorizedDF
 
 __all__ = [
     "check_is",
@@ -33,5 +35,7 @@ __all__ = [
     "MTYPE_REGISTER",
     "MTYPE_LIST_PANEL",
     "MTYPE_LIST_SERIES",
+    "MTYPE_LIST_TABLE",
     "SCITYPE_REGISTER",
+    "VectorizedDF",
 ]
