@@ -30,30 +30,44 @@ import numpy as np
 from deprecated.sphinx import deprecated
 
 from sktime.datatypes._alignment import check_dict_Alignment
+from sktime.datatypes._hierarchical import check_dict_Hierarchical
 from sktime.datatypes._panel import check_dict_Panel
 from sktime.datatypes._registry import mtype_to_scitype
 from sktime.datatypes._series import check_dict_Series
+from sktime.datatypes._table import check_dict_Table
 
 # pool convert_dict-s
 check_dict = dict()
 check_dict.update(check_dict_Series)
 check_dict.update(check_dict_Panel)
+check_dict.update(check_dict_Hierarchical)
 check_dict.update(check_dict_Alignment)
+check_dict.update(check_dict_Table)
 
 
 def _check_scitype_valid(scitype: str = None):
     """Check validity of scitype."""
     valid_scitypes = list(set([x[1] for x in check_dict.keys()]))
 
+    if not isinstance(scitype, str):
+        raise TypeError(f"scitype should be a str but found {type(scitype)}")
+
     if scitype is not None and scitype not in valid_scitypes:
         raise TypeError(scitype + " is not a supported scitype")
 
 
+def _ret(valid, msg, metadata, return_metadata):
+    if return_metadata:
+        return valid, msg, metadata
+    else:
+        return valid
+
+
 #  TODO: remove in v0.11.0
 @deprecated(
     version="v0.10.0",
     reason=(
-        "check_is has been deprecated and will be removed in v0.11.0."
+        "check_is is deprecated since v0.10.0 and will be removed in v0.11.0."
         "Please use check_is_mtype instead."
     ),
     category=FutureWarning,
@@ -86,15 +100,34 @@ def check_is(
             returned only if return_metadata is True
     metadata: dict - metadata about obj if valid, otherwise None
             returned only if return_metadata is True
-        fields:
+        Keys populated depend on (assumed, otherwise identified) scitype of obj.
+        Always returned:
+            "mtype": str, mtype of obj (assumed or inferred)
+            "scitype": str, scitype of obj (assumed or inferred)
+        For scitype "Series":
             "is_univariate": bool, True iff series has one variable
             "is_equally_spaced": bool, True iff series index is equally spaced
-            "mtype": str, mtype of obj if inferred
+            "is_empty": bool, True iff series has no variables or no instances
+            "has_nans": bool, True iff the series contains NaN values
+        For scitype "Panel":
+            "is_univariate": bool, True iff all series in panel have one variable
+            "is_equally_spaced": bool, True iff all series indices are equally spaced
+            "is_equal_length": bool, True iff all series in panel are of equal length
+            "is_empty": bool, True iff one or more of the series in the panel are empty
+            "is_one_series": bool, True iff there is only one series in the panel
+            "has_nans": bool, True iff the panel contains NaN values
+            "n_instances": int, number of instances in the panel
+        For scitype "Table":
+            "is_univariate": bool, True iff table has one variable
+            "is_empty": bool, True iff table has no variables or no instances
+            "has_nans": bool, True iff the panel contains NaN values
+        For scitype "Alignment":
+            currently none
 
     Raises
     ------
     TypeError if no checks defined for mtype/scitype combination
-    ValueError if mtype input argument is not of expected type
+    TypeError if mtype input argument is not of expected type
     """
     return check_is_mtype(
         obj=obj,
@@ -147,8 +180,10 @@ def check_is_mtype(
     ----------
     obj - object to check
     mtype: str or list of str, mtype to check obj as
+        valid mtype strings are in datatypes.MTYPE_REGISTER (1st column)
     scitype: str, optional, scitype to check obj as; default = inferred from mtype
         if inferred from mtype, list elements of mtype need not have same scitype
+        valid mtype strings are in datatypes.SCITYPE_REGISTER (1st column)
     return_metadata - bool, optional, default=False
         if False, returns only "valid" return
         if True, returns all three return objects
@@ -162,24 +197,35 @@ def check_is_mtype(
             returned only if return_metadata is True
     metadata: dict - metadata about obj if valid, otherwise None
             returned only if return_metadata is True
-        fields:
+        Keys populated depend on (assumed, otherwise identified) scitype of obj.
+        Always returned:
+            "mtype": str, mtype of obj (assumed or inferred)
+            "scitype": str, scitype of obj (assumed or inferred)
+        For scitype "Series":
             "is_univariate": bool, True iff series has one variable
             "is_equally_spaced": bool, True iff series index is equally spaced
-            "mtype": str, mtype of obj if inferred
+            "is_empty": bool, True iff series has no variables or no instances
+            "has_nans": bool, True iff the series contains NaN values
+        For scitype "Panel":
+            "is_univariate": bool, True iff all series in panel have one variable
+            "is_equally_spaced": bool, True iff all series indices are equally spaced
+            "is_equal_length": bool, True iff all series in panel are of equal length
+            "is_empty": bool, True iff one or more of the series in the panel are empty
+            "is_one_series": bool, True iff there is only one series in the panel
+            "has_nans": bool, True iff the panel contains NaN values
+            "n_instances": int, number of instances in the panel
+        For scitype "Table":
+            "is_univariate": bool, True iff table has one variable
+            "is_empty": bool, True iff table has no variables or no instances
+            "has_nans": bool, True iff the panel contains NaN values
+        For scitype "Alignment":
+            currently none
 
     Raises
     ------
     TypeError if no checks defined for mtype/scitype combination
     TypeError if mtype input argument is not of expected type
     """
-    _check_scitype_valid(scitype)
-
-    def ret(valid, msg, metadata, return_metadata):
-        if return_metadata:
-            return valid, msg, metadata
-        else:
-            return valid
-
     mtype = _coerce_list_of_str(mtype, var_name="mtype")
 
     valid_keys = check_dict.keys()
@@ -188,11 +234,13 @@ def check_is_mtype(
     #  for each check we remember whether it passed and what it returned
     msg = []
     found_mtype = []
+    found_scitype = []
 
     for m in mtype:
         if scitype is None:
             scitype_of_m = mtype_to_scitype(m)
         else:
+            _check_scitype_valid(scitype)
             scitype_of_m = scitype
         key = (m, scitype_of_m)
         if (m, scitype_of_m) not in valid_keys:
@@ -207,6 +255,7 @@ def check_is_mtype(
 
         if check_passed:
             found_mtype.append(m)
+            found_scitype.append(scitype_of_m)
             final_result = res
         elif return_metadata:
             msg.append(res[1])
@@ -222,6 +271,7 @@ def check_is_mtype(
         if return_metadata:
             # add the mtype return to the metadata
             final_result[2]["mtype"] = found_mtype[0]
+            final_result[2]["scitype"] = found_scitype[0]
             # final_result already has right shape and dependency on return_metadata
             return final_result
         else:
@@ -231,7 +281,7 @@ def check_is_mtype(
         if len(msg) == 1:
             msg = msg[0]
 
-        return ret(False, msg, None, return_metadata)
+        return _ret(False, msg, None, return_metadata)
 
 
 def check_raise(obj, mtype: str, scitype: str = None, var_name: str = "input"):
@@ -241,8 +291,10 @@ def check_raise(obj, mtype: str, scitype: str = None, var_name: str = "input"):
     ----------
     obj - object to check
     mtype: str or list of str, mtype to check obj as
+        valid mtype strings are in datatypes.MTYPE_REGISTER (1st column)
     scitype: str, optional, scitype to check obj as; default = inferred from mtype
         if inferred from mtype, list elements of mtype need not have same scitype
+        valid mtype strings are in datatypes.SCITYPE_REGISTER (1st column)
     var_name: str, optional, default="input" - name of input in error messages
 
     Returns
@@ -272,22 +324,24 @@ def check_raise(obj, mtype: str, scitype: str = None, var_name: str = "input"):
         raise TypeError(msg)
 
 
-def mtype(obj, as_scitype: str = None):
+def mtype(obj, as_scitype: Union[str, List[str]] = None):
     """Infer the mtype of an object considered as a specific scitype.
 
     Parameters
     ----------
     obj : object to infer type of - any type, should comply with and mtype spec
         if as_scitype is provided, this needs to be mtype belonging to scitype
-    as_scitype : str, optional, default=None
-        name of scitype the object "obj" is considered as, finds mtype for that
+    as_scitype : str, list of str, or None, optional, default=None
+        name of scitype(s) the object "obj" is considered as, finds mtype for that
         if None (default), does not assume a specific as_scitype and tests all mtypes
             generally, as_scitype should be provided for maximum efficiency
+        valid scitype type strings are in datatypes.SCITYPE_REGISTER (1st column)
 
     Returns
     -------
     str - the inferred mtype of "obj", a valid mtype string
-        or None, if obj is None
+            or None, if obj is None
+        mtype strings with explanation are in datatypes.MTYPE_REGISTER
 
     Raises
     ------
@@ -296,17 +350,22 @@ def mtype(obj, as_scitype: str = None):
     if obj is None:
         return None
 
-    _check_scitype_valid(as_scitype)
+    if as_scitype is not None:
+        as_scitype = _coerce_list_of_str(as_scitype, var_name="as_scitype")
+        for scitype in as_scitype:
+            _check_scitype_valid(scitype)
 
     if as_scitype is None:
-        mtypes = np.array([x[0] for x in check_dict.keys()])
+        m_plus_scitypes = [(x[0], x[1]) for x in check_dict.keys()]
     else:
-        mtypes = np.array([x[0] for x in check_dict.keys() if x[1] == as_scitype])
+        m_plus_scitypes = [
+            (x[0], x[1]) for x in check_dict.keys() if x[1] in as_scitype
+        ]
 
     res = [
-        mtype
-        for mtype in mtypes
-        if check_is_mtype(obj, mtype=mtype, scitype=as_scitype)
+        m_plus_scitype[0]
+        for m_plus_scitype in m_plus_scitypes
+        if check_is_mtype(obj, mtype=m_plus_scitype[0], scitype=m_plus_scitype[1])
     ]
 
     if len(res) > 1:
@@ -332,6 +391,7 @@ def check_is_scitype(
     ----------
     obj - object to check
     scitype: str or list of str, scitype to check obj as
+        valid mtype strings are in datatypes.SCITYPE_REGISTER
     return_metadata - bool, optional, default=False
         if False, returns only "valid" return
         if True, returns all three return objects
@@ -345,21 +405,35 @@ def check_is_scitype(
             returned only if return_metadata is True
     metadata: dict - metadata about obj if valid, otherwise None
             returned only if return_metadata is True
-        fields:
-            "mtype": str, mtype of obj if inferred
-            "scitype": str, scitype of obj if inferred
-
+        Fields depend on scitpe.
+        Always returned:
+            "mtype": str, mtype of obj (assumed or inferred)
+                mtype strings with explanation are in datatypes.MTYPE_REGISTER
+            "scitype": str, scitype of obj (assumed or inferred)
+                scitype strings with explanation are in datatypes.SCITYPE_REGISTER
+        For scitype "Series":
+            "is_univariate": bool, True iff series has one variable
+            "is_equally_spaced": bool, True iff series index is equally spaced
+            "is_empty": bool, True iff series has no variables or no instances
+            "has_nans": bool, True iff the series contains NaN values
+        For scitype "Panel":
+            "is_univariate": bool, True iff all series in panel have one variable
+            "is_equally_spaced": bool, True iff all series indices are equally spaced
+            "is_equal_length": bool, True iff all series in panel are of equal length
+            "is_empty": bool, True iff one or more of the series in the panel are empty
+            "is_one_series": bool, True iff there is only one series in the panel
+            "has_nans": bool, True iff the panel contains NaN values
+            "n_instances": int, number of instances in the panel
+        For scitype "Table":
+            "is_univariate": bool, True iff table has one variable
+            "is_empty": bool, True iff table has no variables or no instances
+            "has_nans": bool, True iff the panel contains NaN values
+        For scitype "Alignment":
+            currently none
     Raises
     ------
     TypeError if scitype input argument is not of expected type
     """
-
-    def ret(valid, msg, metadata, return_metadata):
-        if return_metadata:
-            return valid, msg, metadata
-        else:
-            return valid
-
     scitype = _coerce_list_of_str(scitype, var_name="scitype")
 
     for x in scitype:
@@ -385,7 +459,7 @@ def check_is_scitype(
 
         if check_passed:
             final_result = res
-            found_mtype.append([0])
+            found_mtype.append(key[0])
             found_scitype.append(key[1])
         elif return_metadata:
             msg.append(res[1])
@@ -412,4 +486,4 @@ def check_is_scitype(
         if len(msg) == 1:
             msg = msg[0]
 
-        return ret(False, msg, None, return_metadata)
+        return _ret(False, msg, None, return_metadata)
