@@ -4,17 +4,18 @@
 # copyright: sktime developers, BSD-3-Clause License (see LICENSE file)
 """
 
-__author__ = ["mloning"]
+__author__ = ["mloning", "kejsitake"]
 __all__ = [
     "test_raises_not_fitted_error",
     "test_score",
     "test_predict_time_index",
+    "test_predict_quantiles",
     "test_update_predict_predicted_index",
     "test_update_predict_predicted_index_update_params",
     "test_y_multivariate_raises_error",
     "test_get_fitted_params",
     "test_predict_time_index_in_sample_full",
-    "test_predict_pred_interval",
+    "test_predict_interval",
     "test_update_predict_single",
     "test_y_invalid_type_raises_error",
     "test_predict_time_index_with_X",
@@ -34,13 +35,12 @@ from sktime.forecasting.tests._config import (
     TEST_ALPHAS,
     TEST_FHS,
     TEST_OOS_FHS,
-    TEST_STEP_LENGTHS,
+    TEST_STEP_LENGTHS_INT,
     TEST_WINDOW_LENGTHS,
     VALID_INDEX_FH_COMBINATIONS,
 )
 from sktime.performance_metrics.forecasting import mean_absolute_percentage_error
 from sktime.registry import all_estimators
-from sktime.utils._testing.estimator_checks import _construct_instance
 from sktime.utils._testing.forecasting import (
     _assert_correct_pred_time_index,
     _get_expected_index_for_update_predict,
@@ -65,10 +65,10 @@ y_train, y_test = temporal_train_test_split(y, train_size=0.75)
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 def test_get_fitted_params(Forecaster):
     """Test get_fitted_params."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     columns = _get_n_columns(f.get_tag("scitype:y"))
     for n_columns in columns:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y_train = _make_series(n_columns=n_columns)
         f.fit(y_train, fh=FH0)
         try:
@@ -83,7 +83,7 @@ def test_get_fitted_params(Forecaster):
 def test_raises_not_fitted_error(Forecaster):
     """Test that calling post-fit methods before fit raises error."""
     # We here check extra method of the forecaster API: update and update_predict.
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
 
     # predict is check in test suite for all estimators
     with pytest.raises(NotFittedError):
@@ -103,7 +103,7 @@ def test_raises_not_fitted_error(Forecaster):
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 def test_y_multivariate_raises_error(Forecaster):
     """Test that wrong y scitype raises error (uni/multivariate if not supported)."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
 
     if f.get_tag("scitype:y") == "univariate":
         y = _make_series(n_columns=2)
@@ -123,7 +123,7 @@ def test_y_multivariate_raises_error(Forecaster):
 @pytest.mark.parametrize("y", INVALID_y_INPUT_TYPES)
 def test_y_invalid_type_raises_error(Forecaster, y):
     """Test that invalid y input types raise error."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     with pytest.raises(TypeError, match=r"type"):
         f.fit(y, fh=FH0)
 
@@ -132,11 +132,11 @@ def test_y_invalid_type_raises_error(Forecaster, y):
 @pytest.mark.parametrize("X", INVALID_X_INPUT_TYPES)
 def test_X_invalid_type_raises_error(Forecaster, X):
     """Test that invalid X input types raise error."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y_train = _make_series(n_columns=n_columns)
         try:
             with pytest.raises(TypeError, match=r"type"):
@@ -153,11 +153,11 @@ def test_X_invalid_type_raises_error(Forecaster, X):
 @pytest.mark.parametrize("steps", TEST_FHS)  # fh steps
 def test_predict_time_index(Forecaster, index_type, fh_type, is_relative, steps):
     """Check that predicted time index matches forecasting horizon."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y_train = _make_series(
             n_columns=n_columns, index_type=index_type, n_timepoints=50
         )
@@ -172,6 +172,37 @@ def test_predict_time_index(Forecaster, index_type, fh_type, is_relative, steps)
             pass
 
 
+@pytest.mark.parametrize("Forecaster", FORECASTERS)
+@pytest.mark.parametrize(
+    "index_type, fh_type, is_relative", VALID_INDEX_FH_COMBINATIONS
+)
+@pytest.mark.parametrize("steps", TEST_FHS)  # fh steps
+def test_predict_residuals(Forecaster, index_type, fh_type, is_relative, steps):
+    """Check that predict_residuals method works as expected."""
+    f = Forecaster.create_test_instance()
+    n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
+
+    for n_columns in n_columns_list:
+        f = Forecaster.create_test_instance()
+        y_train = _make_series(
+            n_columns=n_columns, index_type=index_type, n_timepoints=50
+        )
+        cutoff = y_train.index[-1]
+        fh = _make_fh(cutoff, steps, fh_type, is_relative)
+        try:
+            f.fit(y_train, fh=fh)
+            y_pred = f.predict()
+
+            y_test = _make_series(
+                n_columns=n_columns, index_type=index_type, n_timepoints=len(y_pred)
+            )
+            y_test.index = y_pred.index
+            y_res = f.predict_residuals(y_test)
+            _assert_correct_pred_time_index(y_res.index, y_train.index[-1], fh=fh)
+        except NotImplementedError:
+            pass
+
+
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 @pytest.mark.parametrize(
     "index_type, fh_type, is_relative", VALID_INDEX_FH_COMBINATIONS
@@ -179,7 +210,7 @@ def test_predict_time_index(Forecaster, index_type, fh_type, is_relative, steps)
 @pytest.mark.parametrize("steps", TEST_OOS_FHS)  # fh steps
 def test_predict_time_index_with_X(Forecaster, index_type, fh_type, is_relative, steps):
     """Check that predicted time index matches forecasting horizon."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     z, X = make_forecasting_problem(index_type=index_type, make_X=True)
@@ -187,7 +218,7 @@ def test_predict_time_index_with_X(Forecaster, index_type, fh_type, is_relative,
     # Some estimators may not support all time index types and fh types, hence we
     # need to catch NotImplementedErrors.
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y = _make_series(n_columns=n_columns, index_type=index_type)
         cutoff = y.index[len(y) // 2]
         fh = _make_fh(cutoff, steps, fh_type, is_relative)
@@ -210,11 +241,11 @@ def test_predict_time_index_in_sample_full(
     Forecaster, index_type, fh_type, is_relative
 ):
     """Check that predicted time index equals fh for full in-sample predictions."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y_train = _make_series(n_columns=n_columns, index_type=index_type)
         cutoff = y_train.index[-1]
         steps = -np.arange(len(y_train))
@@ -228,7 +259,9 @@ def test_predict_time_index_in_sample_full(
             pass
 
 
-def _check_pred_ints(pred_ints: list, y_train: pd.Series, y_pred: pd.Series, fh):
+def _check_pred_ints(
+    pred_ints: pd.DataFrame, y_train: pd.Series, y_pred: pd.Series, fh
+):
     # make iterable
     if isinstance(pred_ints, pd.DataFrame):
         pred_ints = [pred_ints]
@@ -239,10 +272,8 @@ def _check_pred_ints(pred_ints: list, y_train: pd.Series, y_pred: pd.Series, fh)
 
         # check time index
         _assert_correct_pred_time_index(pred_int.index, y_train.index[-1], fh)
-
         # check values
-        assert np.all(pred_int["upper"] > y_pred)
-        assert np.all(pred_int["lower"] < y_pred)
+        assert np.all(pred_int["upper"] >= pred_int["lower"])
 
         # check if errors are weakly monotonically increasing
         # pred_errors = y_pred - pred_int["lower"]
@@ -255,9 +286,78 @@ def _check_pred_ints(pred_ints: list, y_train: pd.Series, y_pred: pd.Series, fh)
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
 @pytest.mark.parametrize("alpha", TEST_ALPHAS)
-def test_predict_pred_interval(Forecaster, fh, alpha):
+def test_predict_interval(Forecaster, fh, alpha):
     """Check prediction intervals returned by predict.
 
+    Arguments
+    ---------
+    Forecaster: BaseEstimator class descendant, forecaster to test
+    fh: ForecastingHorizon, fh at which to test prediction
+    alpha: float, coverage at which to make prediction intervals
+
+    Raises
+    ------
+    AssertionError - if Forecaster test instance has "capability:pred_int"
+            and pred. int are not returned correctly when asking predict for them
+    AssertionError - if Forecaster test instance does not have "capability:pred_int"
+            and no NotImplementedError is raised when asking predict for pred.int
+    """
+    f = Forecaster.create_test_instance()
+    n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
+
+    for n_columns in n_columns_list:
+        f = Forecaster.create_test_instance()
+        y_train = _make_series(n_columns=n_columns)
+        f.fit(y_train, fh=fh)
+        if f.get_tag("capability:pred_int"):
+            if f._has_predict_quantiles_been_refactored():
+                y_pred = f.predict()
+                pred_ints = f.predict_interval(fh, coverage=alpha)
+
+                pred_ints = f._convert_new_to_old_pred_int(pred_ints, alpha)
+            else:
+                y_pred, pred_ints = f.predict(return_pred_int=True, alpha=alpha)
+            _check_pred_ints(pred_ints, y_train, y_pred, fh)
+
+        else:
+            with pytest.raises(NotImplementedError, match="prediction intervals"):
+                f.predict(return_pred_int=True, alpha=alpha)
+
+
+def _check_predict_quantiles(
+    pred_quantiles: pd.DataFrame, y_train: pd.Series, fh, alpha
+):
+    # check if the input is a dataframe
+    assert isinstance(pred_quantiles, pd.DataFrame)
+    # check time index (also checks forecasting horizon is more than one element)
+    _assert_correct_pred_time_index(pred_quantiles.index, y_train.index[-1], fh)
+    # Forecasters where name of variables do not exist
+    # In this cases y_train is series - the upper level in dataframe == 'Quantiles'
+    if isinstance(y_train, pd.Series):
+        expected = pd.MultiIndex.from_product([["Quantiles"], [alpha]])
+    else:
+        # multiply variables with all alpha values
+        expected = pd.MultiIndex.from_product([y_train.columns, [alpha]])
+    assert all(expected == pred_quantiles.columns.to_flat_index())
+
+    if isinstance(alpha, list):
+        # sorts the columns that correspond to alpha values
+        pred_quantiles = pred_quantiles.reindex(
+            columns=pred_quantiles.columns.reindex(sorted(alpha), level=1)[0]
+        )
+
+        # check if values are monotonically increasing
+        for var in pred_quantiles.columns.levels[0]:
+            for index in range(len(pred_quantiles.index)):
+                assert pred_quantiles[var].iloc[index].is_monotonic_increasing
+
+
+@pytest.mark.parametrize("Forecaster", FORECASTERS)
+@pytest.mark.parametrize("fh", TEST_OOS_FHS)
+@pytest.mark.parametrize("alpha", TEST_ALPHAS)
+def test_predict_quantiles(Forecaster, fh, alpha):
+    """Check prediction quantiles returned by predict.
+
     Arguments
     ---------
     Forecaster: BaseEstimator class descendant, forecaster to test
@@ -271,66 +371,64 @@ def test_predict_pred_interval(Forecaster, fh, alpha):
     AssertionError - if Forecaster test instance does not have "capability:pred_int"
             and no NotImplementedError is raised when asking predict for pred.int
     """
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
-
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y_train = _make_series(n_columns=n_columns)
         f.fit(y_train, fh=fh)
-        if f.get_tag("capability:pred_int"):
-            y_pred, pred_ints = f.predict(return_pred_int=True, alpha=alpha)
-            _check_pred_ints(pred_ints, y_train, y_pred, fh)
-
-        else:
-            with pytest.raises(NotImplementedError, match="prediction intervals"):
-                f.predict(return_pred_int=True, alpha=alpha)
+        try:
+            quantiles = f.predict_quantiles(fh=fh, alpha=alpha)
+            _check_predict_quantiles(quantiles, y_train, fh, alpha)
+        except NotImplementedError:
+            pass
 
 
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
-@pytest.mark.parametrize("fh", TEST_OOS_FHS)
-@pytest.mark.parametrize("alpha", TEST_ALPHAS)
-def test_predict_quantiles(Forecaster, fh, alpha):
-    f = _construct_instance(Forecaster)
-    n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
-    for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
-        y_train = _make_series(n_columns=n_columns)
-        f.fit(y_train, fh=fh)
-        if not f._has_predict_quantiles_been_refactored():
-            with pytest.raises(NotImplementedError):
-                f.predict_quantiles(fh=fh, alpha=TEST_ALPHAS)
-        else:
-            f.predict_quantiles(fh=fh, alpha=alpha)
+def test_pred_int_tag(Forecaster):
+    """Checks whether the capability:pred_int tag is correctly set.
 
+    Arguments
+    ---------
+    Forecaster: BaseEstimator class descendant, forecaster to test
 
-@pytest.mark.parametrize("Forecaster", FORECASTERS)
-@pytest.mark.parametrize("fh", TEST_OOS_FHS)
-@pytest.mark.parametrize("alpha", TEST_ALPHAS)
-def test_predict_interval(Forecaster, fh, alpha):
-    f = _construct_instance(Forecaster)
-    n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
+    Raises
+    ------
+    ValueError - if capability:pred_int is True, but neither
+        predict_interval nor predict_quantiles have implemented content
+        this can be by direct implementation of _predict_interval or _predict_quantiles
+        or by defaulting to each other and/or _predict_proba
+    """
+    implements_interval = Forecaster._has_implementation_of("_predict_interval")
+    implements_quantiles = Forecaster._has_implementation_of("_predict_quantiles")
+    implements_proba = Forecaster._has_implementation_of("_predict_proba")
 
-    for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
-        y_train = _make_series(n_columns=n_columns)
-        f.fit(y_train, fh=fh)
-        if not f._has_predict_quantiles_been_refactored():
-            with pytest.raises(NotImplementedError):
-                f.predict_interval(fh=fh, coverage=alpha)
-        else:
-            f.predict_interval(fh=fh, coverage=alpha)
+    pred_int_works = implements_interval or implements_quantiles or implements_proba
+
+    if not pred_int_works and Forecaster.get_class_tag("capability:pred_int", False):
+        raise ValueError(
+            f"{Forecaster.__name__} does not implement probabilistic forecasting, "
+            'but "capability:pred_int" flag has been set to True incorrectly. '
+            'The flag "capability:pred_int" should instead be set to False.'
+        )
+
+    if pred_int_works and not Forecaster.get_class_tag("capability:pred_int", False):
+        raise ValueError(
+            f"{Forecaster.__name__} does implement probabilistic forecasting, "
+            'but "capability:pred_int" flag has been set to False incorrectly. '
+            'The flag "capability:pred_int" should instead be set to True.'
+        )
 
 
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
 def test_score(Forecaster, fh):
     """Check score method."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y = _make_series(n_columns=n_columns)
         y_train, y_test = temporal_train_test_split(y)
         f.fit(y_train, fh=fh)
@@ -352,11 +450,11 @@ def test_score(Forecaster, fh):
 @pytest.mark.parametrize("update_params", [True, False])
 def test_update_predict_single(Forecaster, fh, update_params):
     """Check correct time index of update-predict."""
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y = _make_series(n_columns=n_columns)
         y_train, y_test = temporal_train_test_split(y)
         f.fit(y_train, fh=fh)
@@ -367,11 +465,11 @@ def test_update_predict_single(Forecaster, fh, update_params):
 def _check_update_predict_predicted_index(
     Forecaster, fh, window_length, step_length, update_params
 ):
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     n_columns_list = _get_n_columns(f.get_tag("scitype:y"))
 
     for n_columns in n_columns_list:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y = _make_series(n_columns=n_columns, all_positive=True, index_type="datetime")
         y_train, y_test = temporal_train_test_split(y)
         cv = SlidingWindowSplitter(
@@ -392,7 +490,7 @@ def _check_update_predict_predicted_index(
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
 @pytest.mark.parametrize("window_length", TEST_WINDOW_LENGTHS)
-@pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS)
+@pytest.mark.parametrize("step_length", TEST_STEP_LENGTHS_INT)
 @pytest.mark.parametrize("update_params", [False])
 def test_update_predict_predicted_index(
     Forecaster, fh, window_length, step_length, update_params
@@ -421,10 +519,10 @@ def test_update_predict_predicted_index_update_params(
 # test that _y is updated when forecaster is refitted
 @pytest.mark.parametrize("Forecaster", FORECASTERS)
 def test__y_when_refitting(Forecaster):
-    f = _construct_instance(Forecaster)
+    f = Forecaster.create_test_instance()
     columns = _get_n_columns(f.get_tag("scitype:y"))
     for n_columns in columns:
-        f = _construct_instance(Forecaster)
+        f = Forecaster.create_test_instance()
         y_train = _make_series(n_columns=n_columns)
         f.fit(y_train, fh=FH0)
         f.fit(y_train[3:], fh=FH0)
